```
Usage: vcd netpool [OPTIONS] COMMAND [ARGS]...

  Work with network pools in vCloud Director.

      Examples
          vcd netpool list
              Get list of network pools.
      

Options:
  -h, --help  Show this message and exit.

Commands:
  list  list of network pools

```
